﻿using System.Collections.Generic;
using System.IO;
using System.Text.RegularExpressions;
using SharpSvn;

namespace HeuristicLab.Subwcrev {
  class Program {

    static void Main(string[] args) {
      if (args.Length != 0) {
        string path = args[0];
        CreateFiles(path);
      } else {
        System.Console.WriteLine("Enter the Path..");
      }
    }

    public static long GetRevision(string file) {
      SvnClient client = new SvnClient();
      SvnInfoEventArgs info;
      client.GetInfo(file, out info);
      return info.LastChangeRevision;     // Gets the last change revision in which node (or one of its decendent) changed.
    }

    static public void ReplaceInFile(string filePath) {
      string file = Regex.Replace(filePath, ".cs", ".cs.frame");
      string revNo = GetRevision(file).ToString();
      StreamReader reader = new StreamReader(filePath);
      string content = reader.ReadToEnd();
      reader.Close();
      content = Regex.Replace(content, @"\$WCREV\$", revNo);
      StreamWriter writer = new StreamWriter(filePath);
      writer.Write(content);
      writer.Close();
    }

    static public void CreateFiles(string path) {
      string[] pluginFiles = Directory.GetFiles(path, @"*Plugin.cs.frame", SearchOption.AllDirectories);
      string[] assemblyInfoFiles = Directory.GetFiles(path, @"*AssemblyInfo.cs.frame", SearchOption.AllDirectories);
      List<string> Files = new List<string>();
      Files.AddRange(pluginFiles);
      Files.AddRange(assemblyInfoFiles);
      List<string> allFiles = new List<string>();

      foreach (string files in Files) {
        string file = Regex.Replace(files, ".cs.frame", ".cs");          //convert all ".frame" files into ".cs"
        if (!File.Exists(file)) {
          using (SvnClient client = new SvnClient())
          using (Stream to = File.Create(file)) {
            client.Write(new SvnPathTarget(files, SvnRevision.Base), to);
          }
          ReplaceInFile(file);                            //to replace $WCREV$ with revision number.
        }
      }
    }


  }
}
